@@ -2,8 +2,8 @@ from .__version__ import __version__
 from . import errors
 from . import fades
 
-from .dmx_channel   import DmxChannel
+from .dmx_channel   import DmxChannel, DmxChannel16Bit, DmxChannel24Bit, DmxChannel32Bit
 from .dmx_universe  import DmxUniverse
 from .artnet_node   import ArtNetNode
 
-from . import output_correction
\ No newline at end of file
+from . import output_correction
